<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassXC</source>
        <translation>О KeePassXC</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>Участники</translation>
    </message>
    <message>
        <source>Debug Info</source>
        <translation>Отладочная информация</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Скопировать в буфер обмена</translation>
    </message>
    <message>
        <source>Version %1
</source>
        <translation>Версия %1
</translation>
    </message>
    <message>
        <source>Revision: %1</source>
        <translation>Ревизия: %1</translation>
    </message>
    <message>
        <source>Libraries:</source>
        <translation>Библиотеки:</translation>
    </message>
    <message>
        <source>Operating system: %1
CPU architecture: %2
Kernel: %3 %4</source>
        <translation>Операционная система: %1
Архитектура CPU: %2
Ядро: %3 %4</translation>
    </message>
    <message>
        <source>Enabled extensions:</source>
        <translation>Включенные расширения:</translation>
    </message>
    <message>
        <source>Report bugs at: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</source>
        <translation>Сообщать об ошибках: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</translation>
    </message>
    <message>
        <source>KeePassXC is distributed under the terms of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassXC распространяется на условиях Стандартной общественной лицензии GNU (GPL) версии 2 или (на ваше усмотрение) версии 3.</translation>
    </message>
    <message>
        <source>Project Maintainers:</source>
        <translation>Сопровождающие проекта:</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;See Contributions on GitHub&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;Посмотреть вклад на GitHub&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Include the following information whenever you report a bug:</source>
        <translation>Включите следующую информацию, когда сообщаете об ошибке:</translation>
    </message>
    <message>
        <source>Distribution: %1</source>
        <translation>Дистрибутив: %1</translation>
    </message>
</context>
<context>
    <name>AccessControlDialog</name>
    <message>
        <source>Remember this decision</source>
        <translation>Запомнить это решение</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Разрешить</translation>
    </message>
    <message>
        <source>Deny</source>
        <translation>Запретить</translation>
    </message>
    <message>
        <source>%1 has requested access to passwords for the following item(s).
Please select whether you want to allow access.</source>
        <translation>%1 запросил доступ к паролям для следующего элемента(ов).
Разрешить доступ?</translation>
    </message>
    <message>
        <source>KeePassXC HTTP Confirm Access</source>
        <translation>Подтверждение доступа к KeePassXC HTTP</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Невозможно найти запись, соответствующую заголовку окна:</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>Автоввод - KeePassXC</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Последовательность</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Стандартная последовательность</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Выберите запись для автоввода:</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>Автоввод - KeePassXC</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Введите пароль:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Повторите пароль:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Файлы-ключи</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Создать файл-ключ...</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Невозможно создать файл-ключ:</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Выбрать файл-ключ</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Использовать в качестве пароля пустую строку?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Пароли не совпадают.</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Не удалось установить %1 как файл-ключ:
%2</translation>
    </message>
    <message>
        <source>&amp;Key file</source>
        <translation>Файл-&amp;ключ</translation>
    </message>
    <message>
        <source>Cha&amp;llenge Response</source>
        <translation>Запрос ответа</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Empty password</source>
        <translation>Пустой пароль</translation>
    </message>
    <message>
        <source>Changing master key failed: no YubiKey inserted.</source>
        <translation>Не удалось сменить мастер-ключ: ни один YubiKey не вставлен.</translation>
    </message>
</context>
<context>
    <name>CloneDialog</name>
    <message>
        <source>Clone Options</source>
        <translation>Параметры клонирования</translation>
    </message>
    <message>
        <source>Replace username and password with references</source>
        <translation>Использовать ссылки для имени пользователя и пароля</translation>
    </message>
    <message>
        <source>Copy history</source>
        <translation>История копирования</translation>
    </message>
    <message>
        <source>Append &apos; - Clone&apos; to title</source>
        <translation>Добавить к названию « - клон»</translation>
    </message>
</context>
<context>
    <name>CsvImportWidget</name>
    <message>
        <source>Import CSV fields</source>
        <translation>Импорт полей CSV</translation>
    </message>
    <message>
        <source>filename</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <source>size, rows, columns</source>
        <translation>Размер, строки, столбцы</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Кодировка</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Кодек</translation>
    </message>
    <message>
        <source>Text is qualified by</source>
        <translation>Текст соответствует</translation>
    </message>
    <message>
        <source>Fields are separated by</source>
        <translation>Параметры разделены</translation>
    </message>
    <message>
        <source>Comments start with</source>
        <translation>Комментарии начинаются с</translation>
    </message>
    <message>
        <source>First record has field names</source>
        <translation>Первая запись полей</translation>
    </message>
    <message>
        <source>Number of headers line to discard</source>
        <translation>Количество строк заголовков для удаления</translation>
    </message>
    <message>
        <source>Consider &apos;\&apos; an escape character</source>
        <translation>Рассматривать маскирующим символом «\»</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
    <message>
        <source>Column layout</source>
        <translation>Расположение столбцов</translation>
    </message>
    <message>
        <source>Not present in CSV file</source>
        <translation>Отсутствует в CSV файле</translation>
    </message>
    <message>
        <source>Empty fieldname </source>
        <translation>Пустое поле</translation>
    </message>
    <message>
        <source>column </source>
        <translation>Столбец </translation>
    </message>
    <message>
        <source>Imported from CSV file</source>
        <translation>Импортировано из CSV файла</translation>
    </message>
    <message>
        <source>Original data: </source>
        <translation>Исходные данные: </translation>
    </message>
    <message>
        <source>Error(s) detected in CSV file !</source>
        <translation>Обнаружена ошибка в файле CSV!</translation>
    </message>
    <message>
        <source> more messages skipped]</source>
        <translation> пропущено больше сообщений]</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>CSV import: writer has errors:
</source>
        <translation>Импорт CSV: у записи есть ошибки:
</translation>
    </message>
</context>
<context>
    <name>CsvImportWizard</name>
    <message>
        <source>Import CSV file</source>
        <translation>Импорт CSV-файла</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Невозможно вычислить мастер-пароль</translation>
    </message>
</context>
<context>
    <name>CsvParserModel</name>
    <message>
        <source> byte, </source>
        <translation> байт, </translation>
    </message>
    <message>
        <source> rows, </source>
        <translation> строк, </translation>
    </message>
    <message>
        <source> columns</source>
        <translation> столбцов</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Введите мастер-пароль</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Файл-ключ:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Невозможно открыть базу данных.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Не могу открыть файл-ключ</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Файлы-ключи</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Выберите файл-ключ</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Challenge Response:</source>
        <translation>Запрос ответа:</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Восстановить базу данных</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Не могу открыть файл-ключ</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>База данных открылось прекрасно. Больше нечего делать.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Невозможно открыть базу данных.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Успешно</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>База данных была восстановлена.
Теперь можете сохранить её.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Невозможно восстановить базу данных.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Название базы данных:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Описание базы данных:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Раундов преобразований:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Имя пользователя по умолчанию:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>МиБ</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Проверка</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Максимум записей истории:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Максимальный размер истории:</translation>
    </message>
    <message>
        <source>Use recycle bin</source>
        <translation>Использовать корзину</translation>
    </message>
    <message>
        <source>AES:  256 Bit   (default)</source>
        <translation>AES:  256 бит   (по умолчанию)</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation>Twofish:  256 бит</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Алгоритм:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Корень</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>База данных KeePass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Открыть базу данных</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Файл не найден!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Открыть базу данных KeePass 1</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>База данных KeePass 1</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Все файлы (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Закрыть?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Сохранить изменения?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>«%1» изменён.
Сохранить изменения?</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Не удалось записать базу данных.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Сохранить базу данных как</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Новая база данных</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>заблокировано</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Заблокировать базу данных</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Невозможно заблокировать базу данных, так как вы в настоящее время редактируете её.
Нажмите Отмена, чтобы завершить изменения или отклонить их.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Эта база данных никогда не была сохранена.
Можно сохранить базу данных или остановить её заблокированной.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>База данных была изменена.
Сохранить её перед тем, как заблокировать?
В противном случае все изменения будут потеряны.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>«%1» в режиме правки.
Отменить изменения и всё равно закрыть?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Экспортировать базу данных в файл CSV</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>Файл CSV</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Не удалось записать CSV файл.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Не удаётся открыть базу данных.</translation>
    </message>
    <message>
        <source>Merge database</source>
        <translation>Объединить базу данных</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassXC.
Do you want to save it anyway?</source>
        <translation>База данных, в которую пытаетесь сохранить, заблокирована другим экземпляром KeePassXC.
Сохранить в любом случае?</translation>
    </message>
    <message>
        <source>Passwords</source>
        <translation>Пароли</translation>
    </message>
    <message>
        <source>Database already opened</source>
        <translation>База данных уже открыта</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassXC.

Do you want to open it anyway?</source>
        <translation>База данных, которую пытаетесь открыть, заблокирована другим экземпляром KeePassXC.

Открыть в любом случае?</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>Открыть в режиме «только чтение»</translation>
    </message>
    <message>
        <source>File opened in read only mode.</source>
        <translation>Файл открыт в режиме только для чтения.</translation>
    </message>
    <message>
        <source>Open CSV file</source>
        <translation>Открыть файл CSV</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Изменить мастер-пароль</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Удалить запись?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Удалить навсегда запись «%1»?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Удалить записи?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Удалить навсегда %1 записей?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Поместить записи в корзину?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Вы действительно хотите поместить %n запись в корзину?</numerusform><numerusform>Вы действительно хотите поместить %n записи в корзину?</numerusform><numerusform>Вы действительно хотите поместить %n записей в корзину?</numerusform><numerusform>Вы действительно хотите поместить %n записей в корзину?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Удалить группу?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Удалить навсегда группу «%1»?</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Невозможно вычислить мастер-пароль</translation>
    </message>
    <message>
        <source>Move entry to recycle bin?</source>
        <translation>Переместить запись в корзину?</translation>
    </message>
    <message>
        <source>Do you really want to move entry &quot;%1&quot; to the recycle bin?</source>
        <translation>Переместить запись «%1» в корзину?</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <source>No current database.</source>
        <translation>Нет текущей базы данных.</translation>
    </message>
    <message>
        <source>No source database, nothing to do.</source>
        <translation>Нет исходной базы данных, нечего обрабатывать.</translation>
    </message>
    <message>
        <source>Search Results (%1)</source>
        <translation>Результаты поиска (%1)</translation>
    </message>
    <message>
        <source>No Results</source>
        <translation>Нет результатов</translation>
    </message>
    <message>
        <source>Execute command?</source>
        <translation>Выполнить команду?</translation>
    </message>
    <message>
        <source>Do you really want to execute the following command?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</source>
        <translation>Выполнить следующую команду?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Запомнить мой выбор</translation>
    </message>
    <message>
        <source>Autoreload Request</source>
        <translation>Запрос на автозагрузку</translation>
    </message>
    <message>
        <source>The database file has changed. Do you want to load the changes?</source>
        <translation>Файл базу данных изменился. Загрузить изменения?</translation>
    </message>
    <message>
        <source>Merge Request</source>
        <translation>Запрос на слияние</translation>
    </message>
    <message>
        <source>The database file has changed and you have unsaved changes.Do you want to merge your changes?</source>
        <translation>Файл базы данных изменился, а также присутствуют несохранённые изменения. Объединить изменения?</translation>
    </message>
    <message>
        <source>Could not open the new database file while attempting to autoreload this database.</source>
        <translation>Не удалось открыть новый файл базы данных при попытке автоматической перезагрузки этой базы данных.</translation>
    </message>
    <message>
        <source>Empty recycle bin?</source>
        <translation>Очистить корзину?</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete everything from your recycle bin?</source>
        <translation>Удалить все из корзины?</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Запись</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Значок</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Автоввод</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>History</source>
        <translation>История</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>История записи</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Добавить запись</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Править запись</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Пароли не совпадают.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Новый атрибут</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Выбрать файл</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Невозможно открыть файл</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Сохранить вложение</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Невозможно сохранить вложение:
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Завтра</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n неделя</numerusform><numerusform>%n недели</numerusform><numerusform>%n недель</numerusform><numerusform>%n недель</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n месяц</numerusform><numerusform>%n месяца</numerusform><numerusform>%n месяцев</numerusform><numerusform>%n месяцев</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 год</translation>
    </message>
    <message>
        <source>Confirm Remove</source>
        <translation>Подтверждение удаления</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attribute?</source>
        <translation>Удалить этот атрибут?</translation>
    </message>
    <message>
        <source>[PROTECTED] Press reveal to view or edit</source>
        <translation>[Защищён] Нажмите для открытия просмотра или правки</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attachment?</source>
        <translation>Удалить это вложение?</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Дополнительные атрибуты</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Создать</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Вложения</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Изменить имя</translation>
    </message>
    <message>
        <source>Protect</source>
        <translation>Защитить</translation>
    </message>
    <message>
        <source>Reveal</source>
        <translation>Открытие</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Включить автоввод для этой записи</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Заголовок окна:</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the &amp;group</source>
        <translation>Унаследовать стандартную последовательность автоввода от &amp;группы</translation>
    </message>
    <message>
        <source>&amp;Use custom Auto-Type sequence:</source>
        <translation>Использовать сво&amp;ю последовательность автоввода:</translation>
    </message>
    <message>
        <source>Use default se&amp;quence</source>
        <translation>Использовать стан&amp;дартную последовательность</translation>
    </message>
    <message>
        <source>Set custo&amp;m sequence:</source>
        <translation>Установить сво&amp;ю последовательность:</translation>
    </message>
    <message>
        <source>Window Associations</source>
        <translation>Ассоциации окон</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Показать</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Удалить всё</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Пароль ещё раз:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Истекает</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Предустановки</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Примечания:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Значок</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Добавить группу</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Править группу</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Включено</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Выключено</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Наследовать у родительской группы (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Примечания</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Истекает</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Автоввод</translation>
    </message>
    <message>
        <source>&amp;Use default Auto-Type sequence of parent group</source>
        <translation>&amp;Использовать по умолчанию последовательность автоввода родительской группы</translation>
    </message>
    <message>
        <source>Set default Auto-Type se&amp;quence</source>
        <translation>Установить по умолчанию последовательность автоввода</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Add custom icon</source>
        <translation>Добавить свой значок</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Удалить свой значок</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Выбор изображения</translation>
    </message>
    <message>
        <source>Download favicon</source>
        <translation>Скачать значок сайта</translation>
    </message>
    <message>
        <source>Unable to fetch favicon.</source>
        <translation>Не удалось получить значок.</translation>
    </message>
    <message>
        <source>Can&apos;t read icon</source>
        <translation>Не могу прочитать значок</translation>
    </message>
    <message>
        <source>&amp;Use default icon</source>
        <translation>Использовать с&amp;тандартный значок</translation>
    </message>
    <message>
        <source>Use custo&amp;m icon</source>
        <translation>Использовать св&amp;ой значок</translation>
    </message>
    <message>
        <source>Confirm Delete</source>
        <translation>Подтверждение удаления</translation>
    </message>
    <message>
        <source>This icon is used by %1 entries, and will be replaced by the default icon. Are you sure you want to delete it?</source>
        <translation>Этот значок использует %1 записей и будет заменен значком по умолчанию. Хотите удалить его?</translation>
    </message>
    <message>
        <source>Hint: You can enable Google as a fallback under Tools&gt;Settings&gt;Security</source>
        <translation>Подсказка: в качестве резервного варианта для получения значков сайтов возможно использовать  Google. Включите этот параметр в меню «Инструменты» -&gt; «Настройки» -&gt; «Безопасность»</translation>
    </message>
    <message>
        <source>Custom icon already exists</source>
        <translation>Пользовательский значок уже существует</translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Создание:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Изменение:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Доступ:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>UUID:</translation>
    </message>
</context>
<context>
    <name>Entry</name>
    <message>
        <source> - Clone</source>
        <translation> - клон</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Последнее изменение</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Имя записи</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>Адрес</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Имя записи</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Ref: </source>
        <comment>Reference abbreviation</comment>
        <translation>Ссылка: </translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Корзина</translation>
    </message>
</context>
<context>
    <name>HttpPasswordGeneratorWidget</name>
    <message>
        <source>Length:</source>
        <translation>Длина:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Виды символов</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Заглавные буквы</translation>
    </message>
    <message>
        <source>A-Z</source>
        <translation>A-Z</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Строчные буквы</translation>
    </message>
    <message>
        <source>a-z</source>
        <translation>a-z</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Цифры</translation>
    </message>
    <message>
        <source>0-9</source>
        <translation>0-9</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Специальные символы</translation>
    </message>
    <message>
        <source>/*_&amp; ...</source>
        <translation>/*_&amp; ...</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Исключить визуально схожие символы</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>Убедиться, что пароль содержит символы из каждой группы</translation>
    </message>
</context>
<context>
    <name>KMessageWidget</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Close message</source>
        <translation>Закрыть сообщение</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Импортировать базу данных KeePass 1</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Невозможно открыть базу данных.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Невозможно прочесть файл-ключ.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Не база данных KeePass.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Алгоритм шифрования не поддерживается.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Версия базы данных KeePass не поддерживается.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Корень</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Невозможно вычислить мастер-пароль</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Неверный ключ или файл базы данных повреждён.</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Не база данных KeePass.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Версия базы данных KeePass не поддерживается.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Неверный ключ или файл базы данных повреждён.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Невозможно вычислить мастер-пароль</translation>
    </message>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation>Не удалось выполнить запрос ответа.</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database...'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>Выбранный файл от старой KeePass 1 базы данных (.kdb).

Вы можете импортировать его, нажав на База Данных &gt; «Импорт KeePass 1 базы данных...».
Это одностороннее перемещение. Вы не сможете открыть импортированную базу данных на старой версии KeePassX 0,4.</translation>
    </message>
</context>
<context>
    <name>KeePass2Writer</name>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation>Не удалось выполнить запрос ответа.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Невозможно вычислить мастер-пароль</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Неисправимая ошибка в процессе тестирования криптографических функций.</translation>
    </message>
    <message>
        <source>KeePassXC - Error</source>
        <translation>Ошибка - KeePassXC</translation>
    </message>
    <message>
        <source>The lock file could not be created. Single-instance mode disabled.</source>
        <translation>Файл блокировки не может быть создан. Режим недублирующего хранения отключен.</translation>
    </message>
    <message>
        <source>Another instance of KeePassXC is already running.</source>
        <translation>Другой экземпляр KeePassXC уже запущен.</translation>
    </message>
    <message>
        <source>Existing single-instance lock file is invalid. Launching new instance.</source>
        <translation>Запускается новый экземпляр программы, т.к. файл блокировки запуска повреждён.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Open database</source>
        <translation>Открыть базу данных</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Параметры базы данных</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Скопировать имя пользователя в буфер обмена</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Скопировать пароль в буфер обмена</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Показать панель инструментов</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>только для чтения</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Переключить окно</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>База данных KeePass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Сохранить восстановленную базу данных</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Не удалось записать базу данных.</translation>
    </message>
    <message>
        <source>&amp;Recent databases</source>
        <translation>&amp;Недавние базы данных</translation>
    </message>
    <message>
        <source>E&amp;ntries</source>
        <translation>&amp;Записи</translation>
    </message>
    <message>
        <source>Copy att&amp;ribute to clipboard</source>
        <translation>Скопировать &amp;атрибут в буфер обмена</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>&amp;Группы</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>&amp;Save database</source>
        <translation>&amp;Сохранить базу данных</translation>
    </message>
    <message>
        <source>&amp;Close database</source>
        <translation>&amp;Закрыть базу данных</translation>
    </message>
    <message>
        <source>&amp;New database</source>
        <translation>&amp;Новая база данных</translation>
    </message>
    <message>
        <source>Merge from KeePassX database</source>
        <translation>Объединить с базой данных KeePassX</translation>
    </message>
    <message>
        <source>&amp;Add new entry</source>
        <translation>&amp;Создать запись</translation>
    </message>
    <message>
        <source>&amp;View/Edit entry</source>
        <translation>&amp;Открыть/править запись</translation>
    </message>
    <message>
        <source>&amp;Delete entry</source>
        <translation>&amp;Удалить запись</translation>
    </message>
    <message>
        <source>&amp;Add new group</source>
        <translation>&amp;Создать группу</translation>
    </message>
    <message>
        <source>&amp;Edit group</source>
        <translation>&amp;Править группу</translation>
    </message>
    <message>
        <source>&amp;Delete group</source>
        <translation>&amp;Удалить группу</translation>
    </message>
    <message>
        <source>&amp;Database settings</source>
        <translation>Настройки базы данных</translation>
    </message>
    <message>
        <source>&amp;Clone entry</source>
        <translation>&amp;Клонировать запись</translation>
    </message>
    <message>
        <source>Timed one-time password</source>
        <translation>Временный разовый пароль</translation>
    </message>
    <message>
        <source>Copy &amp;TOTP</source>
        <translation>Копировать &amp;ВРП</translation>
    </message>
    <message>
        <source>Show TOTP</source>
        <translation>Показать ВРП</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Найти</translation>
    </message>
    <message>
        <source>Copy &amp;username</source>
        <translation>Скопировать &amp;имя пользователя</translation>
    </message>
    <message>
        <source>Cop&amp;y password</source>
        <translation>&amp;Скопировать пароль</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>&amp;Perform Auto-Type</source>
        <translation>&amp;Произвести автоввод</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>&amp;Открыть адрес</translation>
    </message>
    <message>
        <source>&amp;Lock databases</source>
        <translation>&amp;Заблокировать базу данных</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>&amp;Имя записи</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>&amp;Адрес</translation>
    </message>
    <message>
        <source>&amp;Notes</source>
        <translation>&amp;Примечания</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>Генератор паролей</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Очистить историю</translation>
    </message>
    <message>
        <source>&amp;Database</source>
        <translation>&amp;База данных</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Импорт</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
    <message>
        <source>Empty recycle bin</source>
        <translation>Очистить корзину</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>Ошибка доступа к файлу конфигурации %1</translation>
    </message>
    <message>
        <source>Quit KeePassXC</source>
        <translation>Закрыть KeePassXC</translation>
    </message>
    <message>
        <source>Please touch the button on your YubiKey!</source>
        <translation>Нажмите кнопку на YubiKey!</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>&amp;Open database...</source>
        <translation>&amp;Открыть базу данных...</translation>
    </message>
    <message>
        <source>Sa&amp;ve database as...</source>
        <translation>&amp;Сохранить базу данных как...</translation>
    </message>
    <message>
        <source>Change &amp;master key...</source>
        <translation>Изменение &amp;мастер-пароля...</translation>
    </message>
    <message>
        <source>&amp;Export to CSV file...</source>
        <translation>&amp;Экспорт в CSV-файл...</translation>
    </message>
    <message>
        <source>Import KeePass 1 database...</source>
        <translation>Импортировать базу данных KeePass 1...</translation>
    </message>
    <message>
        <source>Import CSV file...</source>
        <translation>Импорт CSV-файла...</translation>
    </message>
    <message>
        <source>Re&amp;pair database...</source>
        <translation>Во&amp;сстановить базу данных...</translation>
    </message>
    <message>
        <source>Set up TOTP...</source>
        <translation>Установить ВРП...</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Sh&amp;ow a notification when credentials are requested</source>
        <translation>Показывать уведомление при запросе учётных данных</translation>
    </message>
    <message>
        <source>Sort matching entries by &amp;username</source>
        <translation>Сортировать совпавшие записи по &amp;имени пользователя</translation>
    </message>
    <message>
        <source>Re&amp;move all stored permissions from entries in active database</source>
        <translation>Удалить все сохранённые права доступа из записей активной базы данных</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Продвинутые</translation>
    </message>
    <message>
        <source>Always allow &amp;access to entries</source>
        <translation>Всегда разрешать доступ к записям</translation>
    </message>
    <message>
        <source>Always allow &amp;updating entries</source>
        <translation>Всегда разрешать обновление записей</translation>
    </message>
    <message>
        <source>Searc&amp;h in all opened databases for matching entries</source>
        <translation>Искать подходящие записи во всех открытых базах данных</translation>
    </message>
    <message>
        <source>HTTP Port:</source>
        <translation>Порт HTTP:</translation>
    </message>
    <message>
        <source>Default port: 19455</source>
        <translation>Порт по умолчанию: 19455</translation>
    </message>
    <message>
        <source>Re&amp;quest to unlock the database if it is locked</source>
        <translation>Запрашивать разблокировку базы данных, если она заблокирована</translation>
    </message>
    <message>
        <source>Sort &amp;matching entries by title</source>
        <translation>Сортировать совпадающие записи по названию</translation>
    </message>
    <message>
        <source>KeePassXC will listen to this port on 127.0.0.1</source>
        <translation>KeePassXC будет слушать этот порт на 127.0.0.1</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports</source>
        <translation>Не удаётся выполнить привязку к привилегированным портам</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports below 1024!
Using default port 19455.</source>
        <translation>Не удаётся привязать к привилегированным портам с номерами меньше 1024!
Используется порт по умолчанию: 19455.</translation>
    </message>
    <message>
        <source>R&amp;emove all shared encryption keys from active database</source>
        <translation>&amp;Удалить все общие ключи шифрования из активной базы данных</translation>
    </message>
    <message>
        <source>&amp;Return advanced string fields which start with &quot;KPH: &quot;</source>
        <translation>Возвращать продвинутые стро&amp;ковые поля, начинающиеся с «KPH: »</translation>
    </message>
    <message>
        <source>Automatically creating or updating string fields is not supported.</source>
        <translation>Автоматическое создание или обновление полей, содержащих строки, не поддерживается.</translation>
    </message>
    <message>
        <source>This is required for accessing your databases from ChromeIPass or PassIFox</source>
        <translation>Это необходимо для доступа к вашим базам данных из ChromeIPass или PassIFox</translation>
    </message>
    <message>
        <source>Enable KeePassHTTP server</source>
        <translation>Включить сервер KeePassHTTP</translation>
    </message>
    <message>
        <source>Only returns the best matches for a specific URL instead of all entries for the whole domain.</source>
        <translation>Возвращает только лучшие совпадения для определенного URL вместо всех записей для всего домена.</translation>
    </message>
    <message>
        <source>&amp;Return only best matching entries</source>
        <translation>&amp;Показывать только лучшие совпадения</translation>
    </message>
    <message>
        <source>Only entries with the same scheme (http://, https://, ftp://, ...) are returned.</source>
        <translation>Будут отобраны только записи с совпадающим протоколом  (http://, https://, ftp://, ...).</translation>
    </message>
    <message>
        <source>&amp;Match URL schemes</source>
        <translation>&amp;Проверять протокол</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>Генератор паролей</translation>
    </message>
    <message>
        <source>Only the selected database has to be connected with a client.</source>
        <translation>К клиенту должна быть подключена только выбранная база данных.</translation>
    </message>
    <message>
        <source>The following options can be dangerous!
Change them only if you know what you are doing.</source>
        <translation>Следующие параметры могут быть опасны!
Меняйте их, только если знаете, что делаете.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Виды символов</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Заглавные буквы</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Строчные буквы</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Цифры</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Особые символы</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Исключить похожие символы</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Принять</translation>
    </message>
    <message>
        <source>%p%</source>
        <translation>%p%</translation>
    </message>
    <message>
        <source>strength</source>
        <translation>надёжность</translation>
    </message>
    <message>
        <source>entropy</source>
        <translation>энтропия</translation>
    </message>
    <message>
        <source>&amp;Length:</source>
        <translation>&amp;Длина:</translation>
    </message>
    <message>
        <source>Pick characters from every group</source>
        <translation>Подобрать символы из каждой группы</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>Генерировать</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Entropy: %1 bit</source>
        <translation>Энтропия: %1 бит</translation>
    </message>
    <message>
        <source>Password Quality: %1</source>
        <translation>Качество пароля: %1</translation>
    </message>
    <message>
        <source>Poor</source>
        <translation>Плохое</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Слабое</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Хорошее</translation>
    </message>
    <message>
        <source>Excellent</source>
        <translation>Отличное</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Extended ASCII</source>
        <translation>Расширенный ASCII</translation>
    </message>
    <message>
        <source>Passphrase</source>
        <translation>Парольная фраза</translation>
    </message>
    <message>
        <source>Wordlist:</source>
        <translation>Список слов:</translation>
    </message>
    <message>
        <source>Word Count:</source>
        <translation>Количество слов:</translation>
    </message>
    <message>
        <source>Word Separator:</source>
        <translation>Разделитель слов:</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>NULL device</source>
        <translation>Устройство NULL</translation>
    </message>
    <message>
        <source>error reading from device</source>
        <translation>Ошибка чтения из устройства</translation>
    </message>
    <message>
        <source>file empty !
</source>
        <translation>Файл пуст !
</translation>
    </message>
    <message>
        <source>malformed string</source>
        <translation>Неправильная строка</translation>
    </message>
    <message>
        <source>missing closing quote</source>
        <translation>Отсутствует закрывающая цитата</translation>
    </message>
    <message>
        <source>INTERNAL - unget lower bound exceeded</source>
        <translation>Внутренний - превышение нижней границы</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Имя записи</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Примечания</translation>
    </message>
    <message>
        <source>Browser Integration</source>
        <translation>Интеграция с браузером</translation>
    </message>
    <message>
        <source>YubiKey[%1] Challenge Response - Slot %2 - %3</source>
        <translation>YubiKey[%1] Запрос ответа - слот %2 - %3</translation>
    </message>
    <message>
        <source>Press</source>
        <translation>Нажать</translation>
    </message>
    <message>
        <source>Passive</source>
        <translation>Пассивная</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Внутренняя ошибка zlib при сжатии:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Ошибка записи на основное устройство: </translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Ошибка открытия основного устройства: </translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Ошибка чтения с основного устройства: </translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Внутренняя ошибка zlib при распаковке:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Формат gzip не поддерживается в этой версии zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Внутренняя ошибка zlib:</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Case Sensitive</source>
        <translation>Чувствительно к регистру</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Search...</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <source>Limit search to selected group</source>
        <translation>Ограничить поиск выбранной группой</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <source>A shared encryption-key with the name &quot;%1&quot; already exists.
Do you want to overwrite it?</source>
        <translation>Общий ключ шифрования с именем «%1» уже существует.
Перезаписать его?</translation>
    </message>
    <message>
        <source>Do you want to update the information in %1 - %2?</source>
        <translation>Обновить информацию в %1 - %2?</translation>
    </message>
    <message>
        <source>The active database is locked!
Please unlock the selected database or choose another one which is unlocked.</source>
        <translation>Активная база данных заблокирована!
Разблокируйте выбранную базу данных или выберите другую, незаблокированную.</translation>
    </message>
    <message>
        <source>Successfully removed %1 encryption-%2 from KeePassX/Http Settings.</source>
        <translation>Успешно удалено %1 шифрование-%2 из настроек KeePassXC/Http.</translation>
    </message>
    <message>
        <source>No shared encryption-keys found in KeePassHttp Settings.</source>
        <translation>Не найдено общих ключей шифрования в настройках KeePassHttp.</translation>
    </message>
    <message>
        <source>The active database does not contain an entry of KeePassHttp Settings.</source>
        <translation>Активная база данных не содержит записей настроек KeePassHttp.</translation>
    </message>
    <message>
        <source>Removing stored permissions...</source>
        <translation>Удаляю сохранённые права доступа...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Прервать</translation>
    </message>
    <message>
        <source>Successfully removed permissions from %1 %2.</source>
        <translation>Права доступа из %1 %2 успешно удалены.</translation>
    </message>
    <message>
        <source>The active database does not contain an entry with permissions.</source>
        <translation>Активная база данных не содержит записей с назначенными правами доступа.</translation>
    </message>
    <message>
        <source>KeePassXC: New key association request</source>
        <translation>KeePassXC: Запрос на ассоциацию нового ключа</translation>
    </message>
    <message>
        <source>You have received an association request for the above key.
If you would like to allow it access to your KeePassXC database
give it a unique name to identify and accept it.</source>
        <translation>Получен запрос на ассоциацию вышеуказанного ключа.
Если хотите разрешить доступ к базе данных KeePassXC,
дайте ему уникальное имя, чтобы распознать и принять ключ.</translation>
    </message>
    <message>
        <source>KeePassXC: Overwrite existing key?</source>
        <translation>KeePassXC: Перезаписать существующий ключ?</translation>
    </message>
    <message>
        <source>KeePassXC: Update Entry</source>
        <translation>KeePassXC: Обновить запись</translation>
    </message>
    <message>
        <source>KeePassXC: Database locked!</source>
        <translation>KeePassXC: База данных заблокирована!</translation>
    </message>
    <message>
        <source>KeePassXC: Removed keys from database</source>
        <translation>KeePassXC: Ключи удалены из базы данных</translation>
    </message>
    <message>
        <source>KeePassXC: No keys found</source>
        <translation>KeePassXC: Ключи не найдены</translation>
    </message>
    <message>
        <source>KeePassXC: Settings not available!</source>
        <translation>KeePassXC: Настройки недоступны!</translation>
    </message>
    <message>
        <source>KeePassXC: Removed permissions</source>
        <translation>KeePassXC: Права доступа удалены</translation>
    </message>
    <message>
        <source>KeePassXC: No entry with permissions found!</source>
        <translation>KeePassXC: Не найдена запись с правами доступа!</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Параметры приложения</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Безопасность</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>Ошибка доступа к файлу конфигурации %1</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Запоминать последнюю базу данных</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Автоматически сохранять при выходе</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Автоматически сохранять после каждого изменения</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Сворачивать при копировании в буфер обмена</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Использовать значок группы для новых записей</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Глобальная комбинация клавиш для автоввода</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Показывать значок в системном лотке</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>При сворачивании скрывать окно в системный лоток</translation>
    </message>
    <message>
        <source>Load previous databases on startup</source>
        <translation>Загружать предыдущие базы данных при запуске</translation>
    </message>
    <message>
        <source>Automatically reload the database when modified externally</source>
        <translation>Автоматически перезагружать базу данных при её изменении извне</translation>
    </message>
    <message>
        <source>Hide window to system tray instead of app exit</source>
        <translation>Скрывать окно в системный лоток вместо выхода</translation>
    </message>
    <message>
        <source>Minimize window at application startup</source>
        <translation>Сворачивать окно при запуске приложения</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Основные параметры</translation>
    </message>
    <message>
        <source>Remember last key files and security dongles</source>
        <translation>Запоминать последние использованные файлы ключей и устройства</translation>
    </message>
    <message>
        <source>Don&apos;t mark database as modified for non-data changes (e.g., expanding groups)</source>
        <translation>Не помечать базу данных изменённой при действиях, не связанных с изменением данных (например, при распахивании групп)</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Автоввод</translation>
    </message>
    <message>
        <source>Use entry title and URL to match windows for global Auto-Type</source>
        <translation>Использовать для поиска URL и название записи</translation>
    </message>
    <message>
        <source>Always ask before performing Auto-Type</source>
        <translation>Всегда спрашивать перед выполнением автоввода</translation>
    </message>
    <message>
        <source>Auto-Type delay</source>
        <translation>Задержка автоввода</translation>
    </message>
    <message>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <source>Start only a single instance of KeePassXC</source>
        <translation>Запускать только один экземпляр KeePassXC</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Очищать буфер обмена через</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>сек</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Блокировать базу данных при отсутствии активности длительностью</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>По умолчанию показывать пароль в открытую</translation>
    </message>
    <message>
        <source>Lock databases after minimizing the window</source>
        <translation>Блокировать базу данных при сворачивания окна</translation>
    </message>
    <message>
        <source>Don&apos;t require password repeat when it is visible</source>
        <translation>Не требовать повторный ввод пароля, когда он показывается</translation>
    </message>
    <message>
        <source>Timeouts</source>
        <translation>Таймауты</translation>
    </message>
    <message>
        <source>Convenience</source>
        <translation>Удобство</translation>
    </message>
    <message>
        <source>Lock databases when session is locked or lid is closed</source>
        <translation>Блокировать базу данных при закрытии сеанса или закрытии крышки</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Конфиденциальность</translation>
    </message>
    <message>
        <source>Use Google as fallback for downloading website icons</source>
        <translation>Использовать Google в качестве резервного варианта для получения значков веб-сайтов</translation>
    </message>
</context>
<context>
    <name>SetupTotpDialog</name>
    <message>
        <source>Setup TOTP</source>
        <translation>Настроить ВРП</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Ключ:</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>Использовать пользовательские настройки</translation>
    </message>
    <message>
        <source>Note: Change these settings only if you know what you are doing.</source>
        <translation>Примечание. Изменяйте эти параметры, только если знаете, что делаете.</translation>
    </message>
    <message>
        <source>Time step:</source>
        <translation>Шаг по времени:</translation>
    </message>
    <message>
        <source>8 digits</source>
        <translation>8 цифр</translation>
    </message>
    <message>
        <source>6 digits</source>
        <translation>6 цифр</translation>
    </message>
    <message>
        <source>Code size:</source>
        <translation>Размер кода:</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>сек</translation>
    </message>
</context>
<context>
    <name>TotpDialog</name>
    <message>
        <source>Timed Password</source>
        <translation>Временной пароль</translation>
    </message>
    <message>
        <source>000000</source>
        <translation>000000</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Expires in</source>
        <translation>Истекает в</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Разблокировать базу данных</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome to KeePassXC</source>
        <translation>Добро пожаловать в KeePassXC</translation>
    </message>
    <message>
        <source>Start storing your passwords securely in a KeePassXC database</source>
        <translation>Начать безопасное хранение ваших паролей в базе данных KeePassXC</translation>
    </message>
    <message>
        <source>Create new database</source>
        <translation>Создать новую базу данных</translation>
    </message>
    <message>
        <source>Open existing database</source>
        <translation>Открыть существующую базу данных</translation>
    </message>
    <message>
        <source>Import from KeePass 1</source>
        <translation>Импорт из KeePass 1</translation>
    </message>
    <message>
        <source>Import from CSV</source>
        <translation>Импорт из CSV</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Недавние базы данных</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>path to a custom config file</source>
        <translation>путь к своему файлу настроек</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>файл-ключ базы данных</translation>
    </message>
    <message>
        <source>KeePassXC - cross-platform password manager</source>
        <translation>KeePassXC - кроссплатформенный менеджер паролей</translation>
    </message>
    <message>
        <source>read password of the database from stdin</source>
        <translation>читать пароли базы данных из стандартного ввода «stdin»</translation>
    </message>
    <message>
        <source>filenames of the password databases to open (*.kdbx)</source>
        <translation>имена файлов открываемой базы данных паролей (*.kdbx)</translation>
    </message>
    <message>
        <source>Copy a password to the clipboard</source>
        <translation>Скопировать пароль в буфер обмена</translation>
    </message>
    <message>
        <source>Path of the database.</source>
        <translation>Путь к базе данных.</translation>
    </message>
    <message>
        <source>Use a GUI prompt unlocking the database.</source>
        <translation>Использовать подсказку GUI для разблокировки базы данных.</translation>
    </message>
    <message>
        <source>Name of the entry to clip.</source>
        <translation>Имя записи для отсечения.</translation>
    </message>
    <message>
        <source>Extract and print the content of a database.</source>
        <translation>Извлечь и распечатать содержимое базы данных.</translation>
    </message>
    <message>
        <source>Path of the database to extract.</source>
        <translation>Путь к базе данных для извлечения.</translation>
    </message>
    <message>
        <source>Name of the command to execute.</source>
        <translation>Имя выполняемой команды.</translation>
    </message>
    <message>
        <source>List database entries.</source>
        <translation>Список записей в базе данных.</translation>
    </message>
    <message>
        <source>Path of the group to list. Default is /</source>
        <translation>Путь к списку группы. Значение по умолчанию /</translation>
    </message>
    <message>
        <source>Print the UUIDs of the entries and groups.</source>
        <translation>Распечатать UUID записей и групп.</translation>
    </message>
    <message>
        <source>Merge two databases.</source>
        <translation>Объединить две базы данных.</translation>
    </message>
    <message>
        <source>Path of the database to merge into.</source>
        <translation>Путь к базе данных для объединения в.</translation>
    </message>
    <message>
        <source>Path of the database to merge from.</source>
        <translation>Путь к базе данных для слияния.</translation>
    </message>
    <message>
        <source>Use the same password for both database files.</source>
        <translation>Использовать тот же пароль для обоих файлов базы данных.</translation>
    </message>
    <message>
        <source>Show a password.</source>
        <translation>Показать пароль.</translation>
    </message>
    <message>
        <source>Name of the entry to show.</source>
        <translation>Название записи для отображения.</translation>
    </message>
</context>
</TS>